@@ -6,16 +6,16 @@
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2, or (at your option)
  * any later version.
- *                                                                              
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- *                                                                              
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301 USA.
  *
  * The session id generator was taken from the KDE session manager.
  * Copyright (c) 2000 Matthias Ettrich <ettrich@kde.org>
@@ -135,7 +135,7 @@ static const struct
         N_("_Hibernate"),
         "xfsm-hibernate",
         N_("Failed to hibernate")
-    }, 
+    },
 };
 
 static void
@@ -174,7 +174,7 @@ xfsm_logout_plugin_do_dbus_call(XfsmLogoutPlugin *logout_plugin,
     ret = dbus_g_proxy_call(proxy, "Shutdown", error,
                             G_TYPE_UINT, type,
                             G_TYPE_BOOLEAN, logout_plugin->allow_save,
-                            G_TYPE_INVALID);
+                            G_TYPE_INVALID, G_TYPE_INVALID);
     g_object_unref(G_OBJECT(proxy));
 
     return ret;
