@@ -16,8 +16,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301 USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -154,10 +154,6 @@ main (int argc, char **argv)
     {
       shutdown_type = XFSM_SHUTDOWN_HIBERNATE;
     }
-  else if (opt_fast)
-    {
-      allow_save = FALSE;
-    }
   else if (opt_version)
     {
       printf ("%s (Xfce %s)\n\n"
@@ -170,6 +166,11 @@ main (int argc, char **argv)
       return EXIT_SUCCESS;
     }
 
+  if (opt_fast)
+    {
+      allow_save = FALSE;
+    }
+
   dbus_error_init (&derror);
   dbus_conn = dbus_bus_get (DBUS_BUS_SESSION, &derror);
   if (G_UNLIKELY (dbus_conn == NULL))
