@@ -15,8 +15,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301 USA.
  *
  * Parts of this file where taken from gnome-session/logout.c, which
  * was written by Owen Taylor <otaylor@redhat.com>.
@@ -405,7 +405,7 @@ shutdownDialog(const gchar *sessionName, XfsmShutdownType *shutdownType, gboolea
   icon = gtk_icon_theme_load_icon (icon_theme,
                                    "system-log-out",
                                    32,
-                                   GTK_ICON_LOOKUP_GENERIC_FALLBACK,
+                                   0,
                                    NULL);
   if (!icon)
     icon = gtk_icon_theme_load_icon (icon_theme,
@@ -439,7 +439,7 @@ shutdownDialog(const gchar *sessionName, XfsmShutdownType *shutdownType, gboolea
   icon = gtk_icon_theme_load_icon (icon_theme,
                                    "system-reboot",
                                    32,
-                                   GTK_ICON_LOOKUP_GENERIC_FALLBACK,
+                                   0,
                                    NULL);
 
   if (!icon)
@@ -481,7 +481,7 @@ shutdownDialog(const gchar *sessionName, XfsmShutdownType *shutdownType, gboolea
   icon = gtk_icon_theme_load_icon (icon_theme,
                                    "system-shutdown",
                                    32,
-                                   GTK_ICON_LOOKUP_GENERIC_FALLBACK,
+                                   0,
                                    NULL);
 
   if (!icon)
@@ -543,7 +543,7 @@ shutdownDialog(const gchar *sessionName, XfsmShutdownType *shutdownType, gboolea
       icon = gtk_icon_theme_load_icon (icon_theme,
                                        "system-suspend",
                                        32,
-                                       GTK_ICON_LOOKUP_GENERIC_FALLBACK,
+                                       0,
                                        NULL);
 
       if (!icon)
@@ -581,7 +581,7 @@ shutdownDialog(const gchar *sessionName, XfsmShutdownType *shutdownType, gboolea
       icon = gtk_icon_theme_load_icon (icon_theme,
                                        "system-hibernate",
                                        32,
-                                       GTK_ICON_LOOKUP_GENERIC_FALLBACK,
+                                       0,
                                        NULL);
 
       if (!icon)
