@@ -1571,11 +1571,11 @@ xfsm_manager_save_timeout (gpointer user_data)
                 "   Client will be disconnected now.\n\n",
                 xfsm_client_get_id (stdata->client));
 
-  xfsm_manager_close_connection (stdata->manager, stdata->client, TRUE);
-
   /* returning FALSE below will free the data */
   g_object_steal_data (G_OBJECT (stdata->client), "--save-timeout-id");
 
+  xfsm_manager_close_connection (stdata->manager, stdata->client, TRUE);
+
   return FALSE;
 }
 
@@ -1819,6 +1819,7 @@ static void
 xfsm_manager_dbus_init (XfsmManager *manager)
 {
   GError *error = NULL;
+  DBusConnection *connection;
 
   manager->session_bus = dbus_g_bus_get (DBUS_BUS_SESSION, &error);
 
@@ -1830,6 +1831,9 @@ xfsm_manager_dbus_init (XfsmManager *manager)
       return;
     }
 
+  connection = dbus_g_connection_get_connection (manager->session_bus);
+  dbus_connection_set_exit_on_disconnect (connection, FALSE);
+
   dbus_g_connection_register_g_object (manager->session_bus,
                                        "/org/xfce/SessionManager",
                                        G_OBJECT (manager));
